==> bibledit-web-1.0.tar.gz: bibledit-web-1.0/web/administration/scripts/collaboration_repo_data.php <==
<h1><?php echo gettext ("Repository data") ?></h1>
<p><?php echo gettext ("You are now at a stage that the data in Bibledit-Web, and the data in the repository, needs to be synchronized. This means that some action needs to be taken to make these two sets of data the same. Not all the data in Bibledit-Web needs to be synchronized with the repository. It is only the data in the one Bible or the Consultation Notes you are now dealing with.") ?></p>
<?php if ($this->object == "consultationnotes") { ?>
<p><?php echo gettext ("Consultation Notes") ?></p>
<?php } else { ?>
<p><?php echo gettext ("Bible") ?>: <?php echo $this->object ?></p>
<?php } ?>

<p><?php echo gettext ("There are two options:") ?></p>
<ol>
  <li><em><?php echo gettext ("Take the data in the repository.") ?></em> <?php echo gettext ("Taking the data in the repository means that the data in the repository is left as it is, and that a copy of that data overwrites your own data in Bibledit-Web. This option is used most of the time.") ?> <a href="collaboration_take_repo.php?object=<?php echo $this->object ?>"><?php echo gettext ("Take the data in the repository.") ?></a></li>
  <li><em><?php echo gettext ("Take your own data.") ?></em> <?php echo gettext ("Taking your own data means that your data is taken as it is, and that this is copied to the repository, overwriting whatever is there in the repository now.") ?> <a href="collaboration_take_yourself.php?object=<?php echo $this->object ?>"><?php echo gettext ("Take your data.") ?></a></li>
</ol>

==> bibledit-web-1.1.tar.gz: bibledit-web-1.1/web/administration/scripts/collaboration_repo_data.php <==
<?php
/*
Copyright (©) 2003-2013 Teus Benschop.

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
*/
?>
<h1><?php echo gettext ("Repository data") ?></h1>
<p><?php echo gettext ("You are now at a stage that the data in Bibledit-Web, and the data in the repository, needs to be synchronized. This means that some action needs to be taken to make these two sets of data the same. Not all the data in Bibledit-Web needs to be synchronized with the repository. It is only the data in the one Bible or the Consultation Notes you are now dealing with.") ?></p>
<?php if ($this->object == "consultationnotes") { ?>
<p><?php echo gettext ("Consultation Notes") ?></p>
<?php } else { ?>
<p><?php echo gettext ("Bible") ?>: <?php echo $this->object ?></p>
<?php } ?>

<p><?php echo gettext ("There are two options:") ?></p>
<ol>
  <li><em><?php echo gettext ("Take the data in the repository.") ?></em> <?php echo gettext ("Taking the data in the repository means that the data in the repository is left as it is, and that a copy of that data overwrites your own data in Bibledit-Web. This option is used most of the time.") ?> <a href="collaboration_take_repo.php?object=<?php echo $this->object ?>"><?php echo gettext ("Take the data in the repository.") ?></a></li>
  <li><em><?php echo gettext ("Take your own data.") ?></em> <?php echo gettext ("Taking your own data means that your data is taken as it is, and that this is copied to the repository, overwriting whatever is there in the repository now.") ?> <a href="collaboration_take_yourself.php?object=<?php echo $this->object ?>"><?php echo gettext ("Take your data.") ?></a></li>
</ol>
